;;
;; Docbook XML macros
;; 
;; Load in your emacs customization file (e.g. ~/.emacs) with the following
;; command
;; (load "/usr/share/susedoc/etc/emacs_docbook_macros.el" t t)
;;
;; Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
;;
;; This program is free software; you can redistribute it and/or modify it under
;; the terms of the GNU General Public License as published by the Free Software
;; Foundation; either version 2 of the License, or (at your option) any later
;; version.
;;
;; This program is distributed in the hope that it will be useful, but WITHOUT
;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
;; FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
;; details.
;; You should have received a copy of the GNU General Public License along with
;; this program; if not, write to the Free Software Foundation, Inc., 59 Temple
;; Place, Suite 330, Boston, MA 02111-1307 USA
;;
;; Author: Frank Sundermeyer <fs@suse.de>
;;

;; DocBook DOCUMENT
(defvar docbook-root "chapter")
(define-skeleton docbook-docbook
  "Insert a complete novdoc file template."
  (setq docbook-root
    (completing-read (format "Root Element [%s]: " docbook-root)
      '("appendix" "article" "book" "chapter" "glossary" "legalnotice" "part" "preface" "refentry" "sect1" "sect2" "sect3" "sect4" "set")
    nil nil nil nil docbook-root))
    nil
    "<?xml version=\"1.0\" encoding=\"UTF-8\"?>
<!DOCTYPE " str " PUBLIC \"-//OASIS//DTD DocBook XML V4.5//EN\" \"http://www.oasis-open.org/docbook/xml/4.5/docbookx.dtd\" [
  <!ENTITY % entities SYSTEM \"entity-decl.ent\">
  %entities;
]>"\n
    "<" docbook-root " id=\"" _  "\">"\n
    >"<title></title>"\n
    >"<para>"\n
    >""\n
    -1"</para>"\n
    -1"</" docbook-root ">"\n
    \n
)

;; NovDoc DOCUMENT
(defvar docbook-root "chapter")
(define-skeleton docbook-novdoc
  "Insert a complete novdoc file template."
  (setq docbook-root
    (completing-read (format "Root Element [%s]: " docbook-root)
      '("appendix" "article" "book" "chapter" "glossary" "legalnotice" "part" "preface" "refentry" "sect1" "sect2" "sect3" "sect4" "set")
    nil nil nil nil docbook-root))
    nil
    "<?xml version=\"1.0\" encoding=\"UTF-8\"?>
<!DOCTYPE " str " PUBLIC \"-//Novell//DTD NovDoc XML V1.0//EN\" \"novdocx.dtd\" [
  <!ENTITY % NOVDOC.DEACTIVATE.IDREF \"INCLUDE\">
  <!ENTITY % entities SYSTEM \"entity-decl.ent\">
  %entities;
]>"\n
    "<" docbook-root " id=\"" _  "\">"\n
    >"<title></title>"\n
    >"<para>"\n
    >""\n
    -1"</para>"\n
    -1"</" docbook-root ">"\n
    \n
)

;; ANNOTATION
(defvar docbook-annotation-default "warning")
(define-skeleton docbook-annotation
  "Insert a docbook annotation template."
  (setq docbook-annotation-default
    (completing-read (format "Annotation type [%s]: " docbook-annotation-default)
      '("important" "note" "tip" "warning")
    nil 't nil nil docbook-annotation-default))
  \n >
  >"<" str ">"\n
  >"<title>" _ "</title>"\n
  >"<para>"\n
  > ""\n
  -1"</para>"\n
  -1"</" docbook-annotation-default ">"\n
  \n >
)

;; CALLOUT
(define-skeleton docbook-callout
  "Insert a docbook <callout> template."
  \n >
  >"<callout areafs=\"" (skeleton-read "areafs: ") "\">"\n
  >"<para>"\n
  > _ \n
  -1"</para>"\n
  -1"</callout>"\n
  \n >
)

;; COMMENT
(define-skeleton docbook-comment
  "Insert a docbook comment template."
  \n
  "<!-- " user-login-name (format-time-string " %Y-%m-%d") ": 
     " _ "
-->
")

;; FIGURE
(define-skeleton docbook-figure
  "Insert a docbook <figure>."
  >"<figure>"\n
  >"<title>" (skeleton-read "Title: ") "</title>"\n
  >"<mediaobject>"\n
  >"<imageobject role=\"fo\">"\n
  >"<imagedata fileref=\"" (setq v1 (skeleton-read "Filename: ")) "\" width=\"75%\" format=\"PNG\"/>"\n
  -1"</imageobject>"\n
  >"<imageobject role=\"html\">"\n
  >"<imagedata fileref=\""v1"\" width=\"75%\" format=\"PNG\"/>"\n
  -1"</imageobject>"\n
  -1"</mediaobject>"\n
  -1"</figure>"\n
  \n
)

;;INDEXTERM
(define-skeleton docbook-indexterm
  "Insert a docbook <indexterm>."
  nil
  (setq docbook-idx1 ""
        docbook-idx2 ""
        docbook-idx3 "")
  (while (= (length docbook-idx1) 0)
    (setq docbook-idx1 (skeleton-read "Primary: ")))
  ;; ugly hack, but the value returned is always printed - returning
  ;; nil helps
  (and
   (setq docbook-idx2 (skeleton-read "Secondary [Enter to skip]: "))
   (if (> (length docbook-idx2) 0)
       (setq docbook-idx3 (skeleton-read "Tertiary [Enter to skip]: ")))
   nil)
  >"<indexterm>"\n
  >"<primary>" docbook-idx1 "</primary>"
  (if (> (length docbook-idx2) 0)
    (insert "<secondary>" docbook-idx2 "</secondary>"))
  (if (> (length docbook-idx3) 0)
    (insert "<tertiary>" docbook-idx3 "</tertiary>"))\n
  -1"</indexterm>"\n
  \n
)

;; LISTITEM
(define-skeleton docbook-listitem
  "Insert a docbook <listitem> template."
  \n >
  >"<listitem>"\n
  >"<para>"\n
  > _ \n
  -1"</para>"\n
  -1"</listitem>"\n
  \n >
)

;; MENUCHOICE
(define-skeleton docbook-menuchoice
  "Insert a docbook <menuchoice> template."
  >"<menuchoice>"\n
  >"<guimenu>" _ "</guimenu>"\n
  >"<guimenu></guimenu>"\n
  -1"</menuchoice> ")

;; REMARK
(defvar docbook-remark-default "clarity")
(define-skeleton docbook-remark
  "Insert a docbook <remark>."
  (setq docbook-remark-default
    (completing-read (format "Remark condition [%s]: " docbook-remark-default)
      '("trans" "structural" "clarity" "generic" "layout" "needinfo")
    nil nil nil nil docbook-remark-default)
  )
  \n"<remark condition=\"" str "\">"\n
  >(format-time-string "%Y-%m-%d") " - " user-login-name ": " _ \n
  -1"</remark>"\n
  \n >
)

;; SECT
(defvar docbook-sect-default "1")
(define-skeleton docbook-sect
  "Insert a docbook <sect?> template."
  (setq docbook-sect-default
    (completing-read (format "Section level [%s]: " docbook-sect-default)
      '("1" "2" "3" "4")
    nil 't nil nil docbook-sect-default))
  \n >
  >"<sect" str " id=\"" _ "\">"\n
  >"<title></title>"\n
  >"<para>"\n
  > _ \n
  -1"</para>"\n
  -1"</sect" docbook-sect-default ">"\n
  \n >
)  

;; STEP
(define-skeleton docbook-step
  "Insert a docbook <step> template."
  \n >
  >"<step>"\n
  >"<para>"\n
  > _ \n
  -1"</para>"\n
  -1"</step>"\n
  \n >
)

;; TABLE
(defvar docbook-table-count "")
(defvar docbook-table-cols "")
(defvar docbook-table-colwidth "")
(define-skeleton docbook-table
  "Insert a docbook <step> table."
  \n >
  >"<table>"\n
  >"<title>" _ "</title>"\n
  >"<tgroup cols=\"" (setq docbook-table-cols (skeleton-read "Number of columns: ")) "\">"\n
  ;; ugly hack: The setq return value gets printed, returning nil fixes this
  (if (= (length docbook-table-cols) 0)
      (and
       (setq docbook-table-cols "1")
       nil))
  (and
   (setq docbook-table-colwidth (/ 100 (string-to-number docbook-table-cols))
         docbook-table-count 1)
   nil)
  (while (<= docbook-table-count (string-to-number docbook-table-cols))
    (indent-according-to-mode)
    (insert "<colspec colnum=\"" (number-to-string docbook-table-count) "\" colname=\"" (number-to-string docbook-table-count) "\" colwidth=\"" (number-to-string docbook-table-colwidth) "*\"/>")
    (newline)
    (setq docbook-table-count (1+ docbook-table-count)))
  >"<thead>"\n
  >"<row>"\n
  ;; ugly hack
  (and
   (setq docbook-table-count 1)
   nil)
  (while (<= docbook-table-count (string-to-number docbook-table-cols))
    (indent-according-to-mode)
    (insert "<entry><para></para></entry>")
    (newline)
    (setq docbook-table-count (1+ docbook-table-count)))
   (indent-according-to-mode)
  -1"</row>"\n
  -1"</thead>"\n
  >"<tbody>"\n
  >"<row>"\n
  ;; ugly hack
  (and
   (setq docbook-table-count 1)
   nil)
  (while (<= docbook-table-count (string-to-number docbook-table-cols))
    (indent-according-to-mode)
    (insert "<entry><para></para></entry>")
    (newline)
    (setq docbook-table-count (1+ docbook-table-count)))
  (indent-according-to-mode)
  -1"</row>"\n
  -1"</tbody>"\n
  -1"</tgroup>"\n
  -1"</table>"\n
)

;; VARLISTENTRY
(define-skeleton docbook-varlistentry
  "Insert a docbook <varlistentry> template."
  \n >
  >"<varlistentry>"\n
  >"<term></term>"\n
  >"<listitem>"\n
  >"<para>"\n
  > _ \n
  -1"</para>"\n
  -1"</listitem>"\n
  -1"</varlistentry>"\n
  \n >
)

;; Create a new menu and keyboard shortcuts
(add-hook 'sgml-mode-hook
  '(lambda ()
     ;; The keyboard shortcuts
     (define-key sgml-mode-map (kbd "\C-c\C-ca") 'docbook-annotation)
     (define-key sgml-mode-map (kbd "\C-c\C-cc") 'docbook-callout)
     (define-key sgml-mode-map (kbd "\C-c\C-cd") 'docbook-docbook)
     (define-key sgml-mode-map (kbd "\C-c\C-cf") 'docbook-figure)
     (define-key sgml-mode-map (kbd "\C-c\C-ci") 'docbook-indexterm)
     (define-key sgml-mode-map (kbd "\C-c\C-cl") 'docbook-listitem)
     (define-key sgml-mode-map (kbd "\C-c\C-cm") 'docbook-menuchoice)
     (define-key sgml-mode-map (kbd "\C-c\C-cn") 'docbook-novdoc)
     (define-key sgml-mode-map (kbd "\C-c\C-cr") 'docbook-remark)
     (define-key sgml-mode-map (kbd "\C-c\C-cs") 'docbook-sect)
     (define-key sgml-mode-map (kbd "\C-c\C-cp") 'docbook-step)
     (define-key sgml-mode-map (kbd "\C-c\C-ct") 'docbook-table)
     (define-key sgml-mode-map (kbd "\C-c\C-cv") 'docbook-varlistentry)

     ;; The Menu
     (require 'easymenu)
     (easy-menu-define docbook-macros sgml-mode-map "DocBook Marcos"
                      '("DocBook"
                        ["Insert DocBook page template"  docbook-docbook t]
                        ["Insert NovDoc page template"  docbook-novdoc t]
                        "--"
                        ["Insert annotation" docbook-annotation t]
                        ["Insert callout" docbook-callout t]
                        ["Insert comment" docbook-comment t]
                        ["Insert figure" docbook-figure t]
                        ["Insert indexterm" docbook-indexterm t]
                        ["Insert listitem" docbook-listitem t]
                        ["Insert menuchoice" docbook-menuchoice t]
                        ["Insert remark" docbook-remark t]
                        ["Insert sect" docbook-sect t]
                        ["Insert step" docbook-step t]
                        ["Insert table" docbook-table t]
                        ["Insert varlistentry" docbook-varlistentry t]))
     (easy-menu-add docbook-macros sgml-mode-map)
))
