# This Makefile is done specifically for openSUSE and SUSE book
# building. Please submit ideas and updates to <bg (AT) suse (dot) de>
# 
.SUFFIXES:
.SUFFIXES: .fo .xml .pdf .html .jsp .ps .xsl .meta .wiki .txt .ind .idx .dia .fig .svg
.PHONY: all clean pdf-color

# tcsh sets environment variable VENDOR. It shall not fool us.
VENDOR	=

DTDDIR     ?= $(DTDROOT)

CHECKBOT   ?= /usr/bin/suse-checkbot
CB_OPTIONS ?= -v --dontwarn 902 --sleep 0 --timeout 60
CONVERT_OPTS= -type grayscale -colors 256
INK_OPTIONS = -z -w 800
DIA_OPTIONS = -t cairo-svg
FOPOPTIONS ?= -q
REMARKS    ?= 0
ifdef REMARKS
ifneq ($(REMARKS),0)
COMMENTS    = 1
endif
endif
ifdef PROFVENDOR
VENDOR      = --stringparam profile.vendor "$(PROFVENDOR)"
endif
ifdef PROFCONDITION
CONDITION   = --stringparam profile.condition "$(PROFCONDITION)" 
endif
COMMENTS   ?= 0
QUIET      ?=
EXIFTOOL ?= exiftool
ifndef OPTIMIZE
OPTIPNG = /bin/true
endif
# XEP_CONFIG_FILE ?= $(HOME)/.susedoc/xep-config.xml
# STYLENOV is now set in $MAIN
HTMLBIGFILE  := $(DTDDIR)/xslt/html/docbook.xsl
STYLEREMARK  := $(DTDDIR)/xslt/misc/get-remarks.xsl
STYLEROOTIDS := $(DTDDIR)/xslt/misc/get-rootids.xsl
STYLESEARCH  := $(DTDDIR)/xslt/misc/search4includedfiles.xsl
STYLELANG    := $(DTDDIR)/xslt/misc/get-language.xsl
STYLEDESK    := $(DTDDIR)/xslt/desktop/docbook.xsl
STYLE_DOCUMENT := $(DTDDIR)/xslt/yelp/docbook.xsl
STYLEGFX     := $(DTDDIR)/xslt/misc/get-graphics.xsl 
STYLELINKS   := $(DTDDIR)/xslt/misc/get-links.xsl
STYLESVG     := $(DTDDIR)/xslt/misc/fixsvg.xsl
STYLESVG2GRAY:= $(DTDDIR)/xslt/misc/svg.color2grayscale.xsl
STYLEBURN    := $(DTDDIR)/xslt/misc/reduce-from-set.xsl
STYLEINDEX   := $(DTDDIR)/xslt/index/xml2idx.xsl
STYLESEAIND  := $(DTDDIR)/xslt/misc/search4index.xsl
STYLEPUB     := $(DTDDIR)/xslt/epub/db2db.xsl
PROFSTRINGS  := --stringparam profile.arch "$(PROFARCH)" \
	      --stringparam profile.os "$(PROFOS)" \
	      --stringparam show.comments $(COMMENTS) \
	      --stringparam show.remarks $(REMARKS) $(VENDOR) $(CONDITION)
HTMLSTRINGS  := --stringparam base.dir html/$(BOOK)/ \
              --stringparam show.comments $(COMMENTS) \
	      --stringparam show.remarks $(REMARKS)
JSPSTRINGS   := --stringparam base.dir jsp/$(BOOK)/ \
              --stringparam show.comments $(COMMENTS) \
              --stringparam show.remarks $(REMARKS) 
FOSTRINGS    := --stringparam show.comments $(COMMENTS) \
	      --stringparam show.remarks $(REMARKS) \
              --stringparam format.print 1 \
              --param ulink.show 1 \
	      --stringparam dtdroot $(DTDROOT)
# CAUTION: path in FOCOLSTRINGS must end with a trailing /
FOCOLSTRINGS := --stringparam show.comments $(COMMENTS) \
	      --stringparam show.remarks $(REMARKS) \
              --stringparam use.xep.cropmarks 0 \
              --stringparam format.print 0 \
	      --stringparam img.src.path "../images/online/" \
              --param ulink.show 1 \
	      --stringparam dtdroot $(DTDROOT)

METAXSLT    := $(DTDDIR)/xslt/misc/svn2docproperties.xsl
STYLEEXTLINK  := $(DTDDIR)/xslt/profiling/process-xrefs.xsl
# get the profiling stylesheet from $(MAIN)
ifndef STYLENOV
GETXMLSTY    := $(DTDDIR)/xslt/misc/get-xml-stylesheet.xsl
STYLENOV     := $(firstword $(shell xsltproc $(GETXMLSTY) xml/$(MAIN)) $(DTDDIR)/xslt/profiling/novdoc-profile.xsl)
endif
# STYLENOV     ?= $(DTDDIR)/xslt/profiling/novdoc-profile.xsl

# PROFILEDIR is one of the most critical variables. Depending on
# this variable, the profiling is done completely different.
ifneq ("z$(STYLENOV)","z")
ifndef PROFCONDITION
PROFILEDIR  := $(subst ;,-,$(PROFARCH))_$(subst ;,-,$(PROFOS))_$(COMMENTS)_$(REMARKS)
else
PROFILEDIR  := $(subst ;,-,$(PROFARCH))_$(subst ;,-,$(PROFOS))_$(COMMENTS)_$(REMARKS)_$(PROFCONDITION)
endif
else
PROFILEDIR  := noprofile
# STYLENOV    := $(DTDDIR)/xslt/profiling/novdoc-profile.xsl
endif

ifdef ROOTID
ROOTSTRINGS := --stringparam rootid "$(ROOTID)"
endif

ifdef HTMLROOT
HROOTSTRING := --stringparam provo.root "$(HTMLROOT)"
endif

# according to toms, the index file must be relative to the profiled $(MAIN). Thus we don't 
# use a directory for the index file.
ifdef USEINDEX
INDEX       := $(shell xsltproc --xinclude $(ROOTSTRINGS) $(STYLESEAIND) xml/$(MAIN))
INDEXSTRING := --stringparam indexfile $(TMP_BOOK).ind
endif

# DRAFT mode will only work if DRAFT="yes"
ifdef DRAFT
FOSTRINGS    += --stringparam draft.mode "$(DRAFT)" \
                --stringparam xml.source.dir "$(shell pwd)/xml/"
FOCOLSTRINGS += --stringparam draft.mode "$(DRAFT)"
HTMLSTRINGS  += --stringparam draft.mode "$(DRAFT)"
JSPSTRINGS   += --stringparam draft.mode "$(DRAFT)"
endif
# find all xml files in subdirectory xml
# and generate profile targets
SRCFILES    := $(wildcard xml/*.xml)
PROFILES    := $(subst xml/,profiled/$(PROFILEDIR)/,$(SRCFILES))
# METAFILES   := $(addsuffix .meta,$(PROFILES))
DISTPROFILE := $(subst xml/,profiled/dist/,$(SRCFILES))
TEMPDIST    := $(subst xml/,tmp/dist/,$(SRCFILES))
# generate lists of all images in color and gray
SRCPNG      := $(wildcard images/src/png/*.png)
SRCSVG      := $(wildcard images/src/svg/*.svg)
SRCFIG      := $(wildcard images/src/fig/*.fig)
SRCDIA      := $(wildcard images/src/dia/*.dia)
SRCSVGFIG   := $(addprefix images/src/svg/,$(subst fig,svg,$(notdir $(SRCFIG))))
SRCSVGDIA   := $(addprefix images/src/svg/,$(subst dia,svg,$(notdir $(SRCDIA))))
GENSVGFIG   := $(addprefix images/gen/svg/,$(subst fig,svg,$(notdir $(SRCFIG))))
GENSVGDIA   := $(addprefix images/gen/svg/,$(subst dia,svg,$(notdir $(SRCDIA))))
# keep intermediate graphics, don't delete after processing
.SECONDARY: $(subst src,gen,$(SRCPNG) $(SRCSVG)) $(GENSVGFIG) $(GENSVGDIA)
SVGPRINT    := $(addprefix images/print/, $(sort $(notdir $(SRCSVG) $(SRCSVGFIG) \
	       $(SRCSVGDIA) )))
SVGONLINE   := $(addprefix images/online/, $(sort $(notdir $(SRCSVG) $(SRCSVGFIG) \
	       $(SRCSVGDIA) )))
ONLINEIMG   := $(subst images/src/png/, images/online/,$(SRCPNG))
ONLINEIMG   += $(addprefix images/online/,$(subst svg,png, $(notdir $(SVGONLINE))))
PRINTIMG    := $(subst images/online/, images/print/,$(ONLINEIMG))
DOUBLEIMG   := $(sort $(filter $(notdir $(basename $(SRCPNG))), \
                     $(notdir $(basename $(SRCSVG))) \
                     $(notdir $(basename $(SRCFIG))) \
                     $(notdir $(basename $(SRCDIA)))))
ifdef DTDROOT
USED        := $(shell test -f profiled/$(PROFILEDIR)/$(MAIN) && \
		xsltproc $(ROOTSTRINGS) --nonet \
	        --xinclude $(STYLEGFX) profiled/$(PROFILEDIR)/$(MAIN) || \
		xsltproc --nonet --xinclude $(STYLEGFX) xml/$(MAIN))
USED_SVG    := $(addsuffix .svg,$(sort $(filter $(basename $(USED)),\
	        $(notdir $(basename $(SVGONLINE))))))
USED_PNG    := $(addsuffix .png,$(sort $(filter-out \
	        $(notdir $(basename $(USED_SVG))),\
	        $(notdir $(basename $(USED))))))
MISSING     := $(sort $(filter-out $(notdir $(basename $(SRCSVG))) \
                           $(notdir $(basename $(SRCPNG))) \
                           $(notdir $(basename $(SRCFIG))) \
			   $(notdir $(basename $(SRCDIA))), \
                           $(basename $(USED))))
used_lc     := $(shell echo $(USED) | tr [:upper:] [:lower:] )
wrong_cap   := $(filter-out $(used_lc), $(USED))
endif
# make TMP_BOOK to save $(BOOK) when using ROOTID
TMP_BOOK    := $(BOOK)
# Testpage for checking links in our books
TESTPAGE   ?= $(TMP_BOOK)-links.html
# variables for make dist-html:
LL         ?= $(shell xsltproc --nonet $(STYLELANG) xml/$(MAIN))
DESKSTRINGS := --stringparam uselang "${LL}" \
	      --stringparam docpath "@PATH@/"

# The rootid should only be used when manually set
# THE_WHOLE_DOCUMENT is not required in $(MAIN) anymore.
ifdef ROOTID
ifneq ($(ROOTID),THE_WHOLE_DOCUMENT)
TMP_BOOK := $(ROOTID)
ROOTSTRING := --stringparam rootid "$(ROOTID)" 
endif
endif

ifdef PDFNAME
TMP_BOOK := $(PDFNAME)
endif

ifdef SVNROOT
USESVN := $(shell svn pg doc:maintainer xml/$(MAIN))
endif

# Variables are calculated only at the very first call of make.
# Unfortunately, I did not succed in updating the value of the
# variable when doing the update. Therefore, the output of the svn up
# is parsed and checked for the resulting revision.
ifdef USESVN
UPDATES?=$(strip "$(shell svn st -u $(DTDROOT) 2>/dev/null | grep "^.......\*." | wc -l)")
endif

ifdef USEMETA
METASTRING := --stringparam use.meta 1
endif

ifdef USEXHTML
XHTMLSTRING := --stringparam generate.jsp.marker 0
endif

# FOP is always set. Either in system profile, or afterwards in the
# environment file. If it is missing, it is really missing.
# FOP is expected to be
# o an absolute path to a FOP processor
# o just the program name
# o in case of xep, it may also be suse-xep
FOPTYPE = $(subst suse-,,$(notdir $(FOP)))

SUBDIRS := jsp html xml profiled
.PHONY: $(SUBDIRS)

# define the commonly used targets
PHONY: all pdf
all pdf: CHECK_ENVIRONMENT $(PROJECTTOC) $(TMP_BOOK)-$(FOPTYPE).pdf

.PHONY: pdf-color color-pdf
pdf-color color-pdf: $(TMP_BOOK)-$(FOPTYPE)-online.pdf

CHECK_ENVIRONMENT: 
	@if ! test "$(BOOK)" ; then \
	    echo "********************************************************";\
	    echo "You still need to source a Project file."; \
	    echo "Read also the makedoc documentation section »Using make«";\
	    echo "********************************************************";\
	    exit 1; \
	fi

ifdef USESVN
	@if [ $(UPDATES) -gt 0 ] ; then \
		echo "DTDROOT is not at HEAD, please run update"; \
		fi 
	make $(DTDROOT)/make/config.status
endif

include $(DTDROOT)/make/layout.mk
include $(DTDROOT)/make/help.mk
include $(DTDROOT)/make/package.mk
include $(DTDROOT)/make/variables.mk
include $(DTDROOT)/make/obb.mk

# the following targets use variables that are defined in layout.mk
$(XEP_CONFIG_FILE): $(DTDROOT)/etc/XEP/xep-suse.xml
	@mkdir -p $(HOME)/.fonts/truetype
	@cp -a $(DTDROOT)/etc/fonts/* $(HOME)/.fonts/truetype/
	$(DTDROOT)/bin/xepchangefontpath.py $< -o $@

$(FOP_CONFIG_FILE): $(DTDROOT)/etc/FOP/fop-suse.xml
	$(DTDROOT)/bin/fopchangefontpath.py $< -o $@

# HTMLGRAPHICS uses LSTYLECSS from layout.mk. This variable is used to define
# dependencies for dist-html
HTMLGRAPHICS = html/$(BOOK)/$(notdir $(LSTYLECSS)) html/$(BOOK)/navig html/$(BOOK)/admon html/$(BOOK)/callouts html/$(BOOK)/images


.PHONY: force
force:
	touch $(SRCFILES)
	rm -f tmp/$(BOOK).fo
	make all

.PHONY: showvariable
showvariable:
ifndef VARIABLE
	@echo "usage: VARIABLE=some_variable make showvariable"
else
	@echo "$($(VARIABLE))"
endif

.PHONY: check
check: ROOTIDS=$(shell xsltproc --xinclude $(ROOTSTRINGS) $(STYLEROOTIDS) profiled/$(PROFILEDIR)/$(MAIN))
check:
	@echo "XML_CATALOG_FILES = $(XML_CATALOG_FILES)"
	@echo "DTDROOT           = $(DTDROOT)"
	@echo "STYLENOV          = $(STYLENOV)"
	@echo
	@echo "LL                = $(LL)"
	@echo "PROFARCH          = $(PROFARCH)"
	@echo "PROFOS            = $(PROFOS)"
	@echo "MAIN              = $(MAIN)"
	@echo "BOOK              = $(BOOK)"
	@echo "COMMENTS          = $(COMMENTS)"
	@echo "REMARKS           = $(REMARKS)"
	@echo "DISTVER           = $(DISTVER)"
	@echo "FOP               = $(FOP)"
	@echo "ROOTID            = $(ROOTID)"
	@echo "ROOTIDS           = $(ROOTIDS)"
	@echo "DOUBLEIMG         = $(DOUBLEIMG)"
	@echo "MISSING GFX       = $(MISSING)"
	@echo "USED              = $(USED)"
	@echo "PROFILEDIR        = $(PROFILEDIR)"
	@echo "USESVN            = $(USESVN)"
	@echo "STYLEFO           = $(STYLEFO)"
	@echo "STYLEH            = $(STYLEH)"
	@echo "STYLEJ            = $(STYLEJ)"
	@echo "STYLEWIKI         = $(STYLEWIKI)"
	@echo "LAYOUTROOT        = $(LAYOUTROOT)"
	@echo "FOPTYPE           = $(FOPTYPE)"
	@echo "STYLENOV          = $(STYLENOV)"
	@echo "T                 = $(T)"
#	@echo "NOPROFILES        = $(NOPROFILES)"
#	@echo "SRCFILES          = $(SRCFILES)"
#	@echo "PROFILES          = $(PROFILES)"
#	@echo "METAFILES         = $(METAFILES)"
#	@echo "USED              = $(USED)"
#	@echo "ONLINEIMG         = $(ONLINEIMG)"
#	@echo "SVGONLINE         = $(SVGONLINE)"
	@echo "USED_SVG          = $(USED_SVG)"
#	@echo "SRCSVGFIG         = $(SRCSVGFIG)"
	@echo "@F                = $(@F)"
#	@echo "secondary         = $(subst images/print,images/gen,$(SVGPRINT))"
#	@echo ".VARIABLES	 = $(.VARIABLES)"

ifeq ("$(DTDROOT)","/usr/share/susedoc")
# no need to use configure with susedoc.rpm
$(DTDROOT)/make/config.status:
else
$(DTDROOT)/make/config.status: $(DTDROOT)/make/configure.ac $(DTDROOT)/make/Makefile.am
	@echo -en "\033[31m"
	@echo "Please update your configuration in $(DTDROOT)/make. To do this,"
	@echo "do: "
	@echo "cd $(DTDROOT)/make; ./autogen.sh "
	@echo "and follow the instructions printed on your screen."
	@echo -en "\033[m\017";\
	exit 1;
endif

.PHONY: showgfx
showgfx: 
	@if test "$(MISSING)"; then \
	   echo "The following graphics files are missing, please provide them:"; \
	   echo $(MISSING); exit 1 ; \
	fi

# always use make validate before using projectgraphics. You may get
# way too many graphics files if you don't do that.
.PHONY: projectgraphics
projectgraphics: 
	@echo $(addprefix images/gen/svg/,$(USED_SVG)) $(addprefix images/src/png/,$(USED_PNG))

.PHONY: projectfiles
projectfiles: QUIET=@
projectfiles: QUIET2=>& /dev/null
projectfiles: $(PROFILES)
projectfiles: INCLUDED=$(addprefix xml/,$(shell xsltproc $(ROOTSTRING) \
		--nonet --xinclude $(STYLESEARCH) \
		profiled/$(PROFILEDIR)/$(MAIN)) $(MAIN))
projectfiles: ENTITIES=$(shell getentityname.py $(INCLUDED))
projectfiles:
	@echo $(sort $(INCLUDED)) $(addprefix xml/, $(ENTITIES)) Makefile ENV-$(BOOK) .env-profile

.PHONY: remainingfiles
remainingfiles: QUIET=@
remainingfiles: QUIET2=>& /dev/null
remainingfiles: $(PROFILES)
remainingfiles: INCLUDED=$(addprefix xml/,$(shell xsltproc $(ROOTSTRING) \
		--nonet --xinclude $(STYLESEARCH) \
		profiled/$(PROFILEDIR)/$(MAIN)) $(MAIN))
remainingfiles:
	@echo $(sort $(filter-out $(INCLUDED) $(addprefix xml/, $(MAIN)), $(SRCFILES)))

.PHONY: profiledir
profiledir:
	@echo $(PROFILEDIR)

.PHONY: chklink jana
chklink jana: $(PROFILES)
	xsltproc --xinclude --noout $(ROOTSTRING) -o $(TESTPAGE) $(STYLELINKS) \
		 profiled/$(PROFILEDIR)/$(MAIN)
	$(CHECKBOT) --url file://localhost/$(PWD)/$(TESTPAGE) \
		    $(CB_OPTIONS) --file $(BOOK)-checkbot.html

.PHONY: dist-all
dist-all: validate chklink dist-xml dist-html dist color-pdf


# BASE_RELEASE and HEAD_RELEASE are IMMEDIATE variables and have to be 
# updated after svn up. The new revision is taken from the output of svn up
# and then set to BASE_RELEASE. The make call then uses the updated
# BASE_RELEASE when running through CHECK_ENVIRONMENT.
# Let's hope that the output of svn up does not change over the time.
ifdef USESVN
.PHONY: update
update:
	@if [ $(UPDATES) -eq 0 ] ; then    \
		echo "Already at HEAD";    \
	 else                              \
	        (cd $(DTDROOT); svn up; )  \
	 fi;
	@$(MAKE) -f $(DTDROOT)/make/common.mk CHECK_ENVIRONMENT
else
update:
	@echo "Either no SVNROOT set, or the file xml/$(MAIN) has no doc:maintainer set."
endif

.PHONY: directories
directories images/gen/svg images/gen/pdf images/online images/print:
	mkdir -p xml profiled tmp images/{print,online} \
	images/src/{fig,png,svg,dia}

.PHONY: configure
configure: $(DTDROOT)/make/configure.ac
	autoconf -o $(DTDROOT)/make/configure $(DTDROOT)/make/configure.ac 
	(cd $(DTDROOT)/make; ./configure && make install)

.PHONY: dist
dist: ROOTIDS=$(shell xsltproc --xinclude $(STYLEROOTIDS) profiled/$(PROFILEDIR)/$(MAIN))
dist: $(PROFILES)
	mkdir -p $(BOOK)
	for i in $(ROOTIDS); do \
	    make ROOTID=$$i; \
	    mv $$i.pdf $(BOOK); \
	done

.PHONY: dist-html-name
dist-html-name:
	@echo $(TMP_BOOK)_$(LL)-html.tar.bz2

.PHONY: pdf-name
pdf-name:
	@echo $(TMP_BOOK)-$(FOPTYPE).pdf

.PHONY: pdf-color-name color-pdf-name
pdf-color-name color-pdf-name:
	@echo $(TMP_BOOK)-$(FOPTYPE)-online.pdf

.PHONY: epub-name
epub-name:
	@echo epub/$(TMP_BOOK).epub

.PHONY: dist-txt-name
dist-txt-name:
	@echo txt/$(TMP_BOOK).txt.bz2

.PHONY: txt-name
txt-name:
	@echo txt/$(TMP_BOOK).txt

.PHONY: dist-html
dist-html: MANIFEST=--stringparam manifest HTML.manifest --param generate.manifest 1
dist-html: HTML-USED=$(addprefix html/$(BOOK)/images/,$(USED))
dist-html: $(PROFILES) html/$(BOOK)/index.html desktop-files document-files-html provide-color-images
	BZIP2=--best tar cjhf $(TMP_BOOK)_$(LL)-html.tar.bz2 \
	      --exclude=CVS --exclude=.cvsignore --exclude=.svn \
	      --no-recursion -T HTML.manifest $(HTML-USED) html/$(BOOK)/index.html html/$(BOOK)/navig/* \
	      html/$(BOOK)/admon/* html/$(BOOK)/callouts/* \
	      html/$(BOOK)/$(notdir $(LSTYLECSS))

.PHONY: dist-jsp
#dist-jsp: JSP-USED=$(addprefix jsp/$(BOOK)/images/,$(USED))
dist-jsp: $(PROFILES) jsp/$(BOOK)/index.jsp
	BZIP2=--best tar cjhf $(TMP_BOOK)_$(LL)-jsp.tar.bz2 \
	      --exclude=CVS --exclude=.cvsignore --exclude=.svn \
	      jsp

.PHONY: dist-txt
dist-txt: txt
	bzip2 -9 -f txt/$(TMP_BOOK).txt

.PHONY: dublin
dublin: $(PROFILES)
dublin: XMLFILES=$(addprefix xml/,$(shell xsltproc $(ROOTSTRING) --nonet --xinclude $(STYLESEARCH) profiled/$(PROFILEDIR)/$(MAIN)))
dublin: BASEFILES=$(filter-out $(OMIT),$(notdir $(basename $(XMLFILES))))
dublin:
	mkdir -p diffs
	for i in $(BASEFILES); do \
	  echo $$i; \
	  xmldiff -f $(FROM) -t $(TO) -d diffs -p -n $(addprefix xml/,$$i).xml;\
	  mv $$i--diff.txt diffs;\
	done 

# Doing dist-xml and dist-book is a bit of a pain. The major problem is,
# that for dist, I want to recover at least several of the entities.
# We will always rebuild the profiling, therefore only one directory
# profiled/dist is needed.
.PHONY: dist-xml
dist-xml: link-entity-dist
dist-xml: $(DISTPROFILE)
dist-xml: INCLUDED=$(addprefix xml/,$(shell xsltproc --nonet --xinclude \
	$(STYLESEARCH) profiled/dist/$(MAIN)) $(MAIN))
dist-xml: ENTITIES=$(shell getentityname.py $(INCLUDED))
dist-xml:
	@if [ $(REMARKS) -ne 0 -a  $(COMMENTS) -ne 0 ]; then \
	   echo "Do not activate COMMENTS or REMARKS for target dist-xml"; \
		exit 1; \
	   fi
	(cd profiled/; rm -f xml; ln -s dist xml; \
	   tar chf ../$(BOOK)_$(LL).tar $(INCLUDED)\
	      $(addprefix xml/,$(ENTITIES)); rm xml )
	tar rf $(BOOK)_$(LL).tar Makefile ENV-$(BOOK) .env-profile
	test -f $(BOOK)_$(LL).tar.bz2 && old $(BOOK)_$(LL).tar.bz2 || true
	bzip2 -9 $(BOOK)_$(LL).tar


.PHONY: dist-book
dist-book: link-entity-dist
dist-book: $(DISTPROFILE)
dist-book: INCLUDED=$(addprefix xml/,$(shell xsltproc --nonet \
	$(ROOTSTRINGS) --xinclude $(STYLESEARCH) \
	profiled/dist/$(MAIN)) $(MAIN)) 
dist-book: ENTITIES=$(shell getentityname.py $(INCLUDED))
dist-book: TOTRANSFILES=$(shell dm.py dg -P --include="doc:trans=yes" -H -A -q "%{name} ")
dist-book:
	@if [ $(REMARKS) -ne 0 -a  $(COMMENTS) -ne 0 ]; then \
	   echo "Do not activate COMMENTS or REMARKS for target dist-book"; \
		exit 1; \
	   fi
	(cd profiled/; rm -f xml; ln -s dist xml; \
	   tar chf ../$(BOOK)_$(LL).tar $(INCLUDED)\
	      $(addprefix xml/, $(ENTITIES)); rm xml )
	tar rf $(BOOK)_$(LL).tar Makefile ENV-$(BOOK) .env-profile
	test -f $(BOOK)_$(LL).tar.bz2 && old $(BOOK)_$(LL).tar.bz2 || true
	bzip2 -9 $(BOOK)_$(LL).tar


# dist-graphics always tries to use the colour images. However we still want
# to convert arbitrary foreign formats like fig or dia to svg first.
# Those converted files are exported as SVG, which creates an additional ostacle
# for the build mechanics. All SVG sources must be in images/src/svg to be able
# calculate the needed USED_* variables. Therefore, we repackage the SVG files
# in a way, that the exported archive contains them in exactly this path.
.PHONY: dist-graphics
dist-graphics: provide-color-images
dist-graphics: $(addprefix images/gen/svg/,$(USED_SVG))
	@echo "Creating graphics archive:"
	@echo -en "\033[31m"
	@echo "**************************************************************************"
	@echo "Warning:"
	@echo "========"
	@echo "Before running dist-graphics, you should run the target validate. The list "
	@echo "of packaged graphics may be way bigger than expected if you don't "
	@echo "have a profiled version of your docs available."
	@echo "**************************************************************************"
	@echo -en "\033[m\017"
ifneq ("z$(USED_SVG)$(USED_PNG)", "z")
	test -h images/gen/src || ln -sf . images/gen/src
	test -h images/gen/images || ln -sf . images/gen/images
	tar chf $(TMP_BOOK)_$(LL)-graphics.tar \
	                 --exclude=CVS --exclude=.cvsignore \
			 --exclude=.svn --ignore-failed-read \
			 $(addprefix images/src/png/,$(USED_PNG))
	(cd images/gen; tar rhf ../../$(TMP_BOOK)_$(LL)-graphics.tar \
	                 --exclude=CVS --exclude=.cvsignore \
			 --exclude=.svn --ignore-failed-read \
	                 $(addprefix images/src/svg/,$(USED_SVG)) )
	test -f $(TMP_BOOK)_$(LL)-graphics.tar.bz2 && old $(TMP_BOOK)_$(LL)-graphics.tar.bz2 || true
	bzip2 -9 $(TMP_BOOK)_$(LL)-graphics.tar
	rm images/gen/{src,images}
else
	@echo -en "\033[32m"
	@echo "No graphics included in selected book."
	@echo -en "\033[m\017"
endif

# dist-graphics-png creates an archive with all graphics in png format. 
dist-graphics-png: $(addprefix images/online/,$(USED))
ifneq ("z$(USED)", "z")
	BZIP2=--best tar cjhf $(TMP_BOOK)_$(LL)-png-graphics.tar.bz2 \
		--exclude=CVS --exclude=.cvsignore \
		--exclude=.svn --ignore-failed-read \
		$(addprefix images/online/,$(USED))
else
	@echo -en "\033[32m"
	@echo "No graphics included in selected book."
	@echo -en "\033[m\017"
endif


.PHONY: clean
clean: directories
	find profiled -name "*.xml" | xargs rm -f
	find profiled -name "PROJECTFILE.*" | xargs rm -f
	find images/gen/ -type f | xargs rm -f
	rm -rf tmp/* images/print/* images/online/*

# this is legacy. Not really needed anymore, but still used sometimes
.PHONY: prof profile
prof profile: $(PROFILES)

.PHONY: validate
profiled/$(PROFILEDIR)/.validate validate: $(PROFILES)
	@echo -e "\033[32m***********Profiling done, validating ....\033[m\017"
	xmllint --noent --postvalid --noout --xinclude profiled/$(PROFILEDIR)/$(MAIN)
	touch profiled/$(PROFILEDIR)/.validate
	@echo -e "\033[32m***********Validating done            ....\033[m\017"

# target to find validation errors in bigfile
# obsolete for xmllint version 2.6.15 and later
.PHONY: bigfile
bigfile: tmp/$(BOOK).xml
	xmllint --noent --postvalid --noout --xinclude tmp/$(BOOK).xml
	xmllint --noent --valid --noout tmp/$(BOOK).xml

.PHONY: bigfile-reduced
bigfile-reduced: tmp/$(BOOK).xml
	xsltproc --output tmp/$(BOOK)-reduced.xml $(ROOTSTRING) $(STYLEBURN) $< 
	xmllint --noent --valid --noout tmp/$(BOOK)-reduced.xml

.PHONY: html
html: cur-dir := $(shell pwd)
html: profiled/$(PROFILEDIR)/.validate html/$(BOOK)/index.html
	@echo "Find the book at: file:$(cur-dir)/html/$(BOOK)/index.html"

.PHONY: jsp
jsp: cur-dir := $(shell pwd)
jsp: profiled/$(PROFILEDIR)/.validate jsp/$(BOOK)/index.jsp
	@echo "Find the book at: file:$(cur-dir)/jsp/$(BOOK)/index.jsp"

.PHONY: html-single
html-single: cur-dir := $(shell pwd)
html-single: profiled/$(PROFILEDIR)/.validate html/$(BOOK)/$(BOOK).html
	@echo "Find the book at: file:$(cur-dir)/html/$(BOOK)/$(BOOK).html"

.PHONY: txt
txt: cur-dir := $(shell pwd)
txt: txt/$(TMP_BOOK).txt
	@echo "Find the book at: file:$(cur-dir)/txt/$(TMP_BOOK).txt"

.PHONY: man
man: tmp/$(BOOK).xml
	xsltproc $(ROOTSTRING) $(STYLEMAN) tmp/$(BOOK).xml

.PHONY: penguin
penguin:
	@echo -e "\033[32m"
	@echo " >o)"
	@echo " /\\"
	@echo "_\_v"
	@echo -e "\033[m\017"

.PHONY: offspring
offspring:
	@echo -e "\033[32m"
	@echo "(o_ (o_ (o_ (o_"
	@echo "(/) (/) (/) (/)"
	@echo -e "\033[m\017"

# show all remarks
.PHONY: show-remarks
show-remarks: REMARKS=1
show-remarks: COMMENTS=1
show-remarks: $(PROFILES)
	xsltproc --nonet --xinclude $(STYLEREMARK)  profiled/$(PROFILEDIR)/$(MAIN)

# Keep some temporary files, to reduce the need of rebuilding
# Use variable BOOK from the profiling information
tmp/$(TMP_BOOK)-$(FOPTYPE).fo:

tmp/$(TMP_BOOK)-$(FOPTYPE)-online.fo:

$(SRCSVGFIG):

$(SRCSVGDIA):

# the following rules are for normal profiling and for doing a
# dist profile. This works, because "dist" will never be a PROFILEDIR
# as defined somewhere far up in this Makefile. Later on, dist-xml and
# dist-book will require the build of profiled/dist/%.xml instead of
# the $(PROFILEDIR).
# Depending if we have a profiling stylesheet, the profiling will be done,
# or just a symbolic link is used.
# During the profiling, we have to protect all entities in the text,
# because they would be resolved else. The intermediate files without
# entities resides in tmp/dist/xml . The sed scripts that are used to
# protect the entities and convert them back are 
# $(DTDROOT)/etc/entities.preserve.sed and
# $(DTDROOT)/etc/entities.recover.sed
# Without the .SECONDARY flag, the intermediate links would be deleted
# in the case of no profiling.
.SECONDARY: $(addprefix tmp/dist/,$(SRCFILES))
tmp/dist/%.xml: tmp/dist/PROJECTFILE.$(BOOK)
tmp/dist/%.xml: %.xml
ifneq ("z$(STYLENOV)", "z") 
	rm -f $@
	mkdir -p $(dir $@)
	$(QUIET)suse-entities-exchange.sh -s -o $(subst $<,,$@) -d preserve $<
else
	@mkdir -p $(dir $@)
	$(QUIET)ln -sf ../../../$< $@
endif


profiled/dist/%.xml: tmp/dist/xml/%.xml
ifneq ("z$(STYLENOV)", "z") 
	rm -f $@
	$(QUIET)suse-entities-exchange.sh -s -d preserve $<
	$(QUIET)xsltproc --nonet --output $@ \
		$(subst show.remarks 1,show.remarks 0, \
		  $(subst show.comments 1,show.comments 0, \
		  $(PROFSTRINGS))) \
	        --stringparam filename "$(notdir $<)" \
	        $(STYLENOV) $< $(QUIET2)
	$(QUIET)suse-entities-exchange.sh -d recover $@
else
	$(QUIET)ln -sf ../../$< $@
endif

# I need to link the entity-decl.ent in addition to all other xml files
# because the entities are not resolved when just linking.
# CAUTION:
# There are two cases that have to be looked at when linking entities: 
# a) make profile without a profiling stylesheet set (xml files will be just
#    linked into profiled/noprofile)
# b) make dist* 
# both cases are selected at the appropriate place when doing the profiling step. 
# The overhead to have just one target for this routine is not worth the effort.

.PHONY: link-entity-dist
link-entity-dist: ENTITIES=$(shell getentityname.py xml/$(MAIN))
link-entity-dist: $(shell rm -rf profiled/dist; mkdir -p profiled/dist)
link-entity-dist: $(shell rm -rf tmp/dist/xml; mkdir -p tmp/dist/xml)
link-entity-dist:
	for i in $(ENTITIES); do \
		ln -sf ../../xml/$$i profiled/dist/$$i; \
		ln -sf ../../../xml/$$i tmp/dist/xml/$$i; done

.PHONY: link-entity-noprofile
link-entity-noprofile: ENTITIES=$(shell getentityname.py xml/$(MAIN))
link-entity-noprofile: $(shell mkdir -p profiled/noprofile)
link-entity-noprofile:
	$(QUIET)for i in $(ENTITIES); do ln -sf ../../xml/$$i profiled/noprofile/$$i; done

# Now do the normal profiling. The entity declarations are needed for the
# target dist-xml because we want to recover all the entities after the
# profiling step when exporting our xml.
# If STYLENOV is undefined, there is no profiling information in $MAIN. This means,
# we will continue without profilation. However, it may happen that even then an 
# entity file is provided which we must link to the profiled/noprofile directory.
ifneq ("z$(STYLENOV)", "z") 
profiled/$(PROFILEDIR)/%.xml: xml/%.xml
else
profiled/$(PROFILEDIR)/%.xml: xml/%.xml link-entity-noprofile
endif
ifneq ("z$(STYLENOV)", "z") 
	$(QUIET)xsltproc --nonet --output $@ $(PROFSTRINGS) \
	        --stringparam filename "$(notdir $<)" \
		$(HROOTSTRING) \
	        $(STYLENOV) $< $(QUIET2)
else
	$(QUIET)ln -sf ../../$< $@
endif

.PHONY: optipng
optipng:
	exiftool -Comment=optipng -overwrite_original -P \
	$(shell for i in $(addprefix images/src/png/,$(USED_PNG)); do  \
		exiftool -Comment $$i  | grep optipng > /dev/null || \
		optipng -o8 $$i > /dev/null; \
		echo "$$i "; \
		done )

warn-images:
	@if test "$(DOUBLEIMG)"; then \
	    echo -en "\033[31m";\
	    echo "**************************************************";\
	    echo "WARNING: image names are not unique"; \
	    echo "multiple sources available for the image(s):";\
	    echo "$(DOUBLEIMG)"; \
	    echo "**************************************************";\
            echo -en "\033[m\017";\
	fi; \
	if test "$(wrong_cap)"; then \
	    echo -en "\033[31m";\
	    echo "**************************************************";\
	    echo "WARNING: not all image names are lower case."; \
	    echo "This will make problems when creating online docs:";\
	    echo "$(wrong_cap)"; \
	    echo "**************************************************";\
            echo -en "\033[m\017";\
	fi

# This works as follows:
# o images in this Makefile are generally generated by running one of the
#   targets provide-images or provide-color-images.
# o the tmp directory is needed when converting svg to svg to png. svg to svg
#   is done to improve the xml of svg or to create grayscale svg.
.PHONY: provide-images
provide-images: $(SVGPRINT) $(PRINTIMG)

.PHONY: provide-color-images
provide-color-images: $(SVGONLINE) $(ONLINEIMG)

.PHONY: provide-epub-images
provide-epub-images: provide-color-images
	mkdir -p epub
	ln -sf ../images/online epub/images

images/print/%.svg: images/gen/svg/%.svg
	xsltproc $(STYLESVG) $< | \
	xsltproc $(STYLESVG2GRAY) - > $@

images/online/%.svg: images/gen/svg/%.svg
	xsltproc $(STYLESVG) $< > $@

# gray images are not in our subversion, we have to create them on the fly.
# we do not want to optimize again for the printshop only.
images/print/%.png: images/src/png/%.png
	convert $< $(CONVERT_OPTS) $@

images/print/%.png: images/gen/png/%.png
	convert $< $(CONVERT_OPTS) $@

images/gen/png/%.png: images/gen/svg/%.svg
	if test -L $@; then \
	    rm -f $@; \
	fi
	inkscape $(INK_OPTIONS) -e $@ -f $<

# color images are just linked. 
images/online/%.png: images/src/png/%.png
	@$(EXIFTOOL) -Comment $< | grep optipng > /dev/null || \
	    (echo -en "\033[31m";\
	    echo "Warning: $< not optimized. ";\
	    echo "Run make optipng and check in the modified pictures"; \
	    echo -en "\033[m\017")
	ln -sf ../src/png/$(notdir $<) $@

images/online/%.png: images/gen/svg/%.svg
	if test -L $@; then \
	    rm -f $@; \
	fi
	inkscape $(INK_OPTIONS) -e $@ -f $<
	$(OPTIPNG) -o8 $@ >& /dev/null

images/gen/svg/%.svg: images/src/fig/%.fig
	fig2dev -L svg $< $@

images/gen/svg/%.svg: images/src/dia/%.dia
	LANG=C dia $(DIA_OPTIONS) --export=$@ $<

images/gen/svg/%.svg: images/src/svg/%.svg
	ln -sf ../../src/svg/$(notdir $<) $@

# we do not use pdf currently. If we change that, we should create a 
# directory images/gen/pdf to collect all the converted graphics.
#
# tmp/%.pdf: images/src/svg/%.svg
# 	inkscape --export-pdf=$@ -f $<
# 
# tmp/%.pdf: images/src/dia/%.dia
# 	LANG=C dia $(DIA_OPTIONS) --export=$@ $<
# 
# tmp/%.pdf: images/src/fig/%.fig
# 	fig2dev -L pdf $< $@

# Generate $(BOOK).xml from the profiled xml files
# needed for bigfile and manual pages
tmp/$(BOOK).xml: $(PROFILES) 
	xsltproc --xinclude --output $@ --stringparam resolve.suse-pi 1 \
	--stringparam projectfile PROJECTFILE.$(BOOK) $(STYLENOV) \
	profiled/$(PROFILEDIR)/$(MAIN)

online-docs-$(BOOK)/$(MAIN): tmp/$(BOOK).xml
	xsltproc --nonet --output $@ \
	        $(STYLENOV) $<

online-localized-$(BOOK)/$(MAIN): tmp/$(BOOK).xml
	xsltproc --nonet --output $@ $(ROOTSTRING) \
		--param use.id.as.filename 1 \
	        $(STYLEEXTLINK) $<

# in the following target, the mkdir of the directory has to go into
# the shell loop in addition to the target, because $(shell ) calls seem
# to be handled out of order. At least without that mkdir, it happened
# to me that make tried to create the links when the directory still was
# not present (to be exact, the shell command was executed before any
# other command in the target).
# The following will not work because in xml/*.xml there are no xml:base
# attributes available. Using xml/$MAIN instead.
#profiled/$(PROFILEDIR)/PROJECTFILE: INCLUDED=$(addprefix xml/, \
	$(shell xsltproc $(ROOTSTRING) --nonet --xinclude --xinclude \
	$(STYLESEARCH) xml/$(MAIN)) $(MAIN))
# still have to add IENTITIES to the echo to define which entity file
# is included in PROJECTFILE
profiled/$(PROFILEDIR)/PROJECTFILE.$(BOOK): IENTITIES=$(shell getentityname.py -f xml/$(MAIN))
profiled/$(PROFILEDIR)/PROJECTFILE.$(BOOK): ENTITIES=$(shell getentityname.py xml/$(MAIN))
profiled/$(PROFILEDIR)/PROJECTFILE.$(BOOK) tmp/dist/PROJECTFILE.$(BOOK): ENV-$(BOOK)
	$(shell mkdir -p $(dir $@); for env in $(ENTITIES); do ln -sf ../../xml/$$env profiled/$(PROFILEDIR)/; done ) 
	@echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?>" > $@
	@echo "<!DOCTYPE docproperties [  " >> $@
	@echo "<!ENTITY % ISOlat1 PUBLIC  " >> $@
	@echo " \"ISO 8879:1986//ENTITIES Added Latin 1//EN//XML\" " >> $@
	@echo " \"http://www.oasis-open.org/docbook/xml/4.3/ent/iso-lat1.ent\">" >> $@
	@echo "<!ENTITY % ISOlat2 PUBLIC  " >> $@
	@echo " \"ISO 8879:1986//ENTITIES Added Latin 2//EN//XML\" " >> $@
	@echo " \"http://www.oasis-open.org/docbook/xml/4.3/ent/iso-lat2.ent\">" >> $@
	@echo "<!ENTITY % ISOnum PUBLIC  " >> $@
	@echo " \"ISO 8879:1986//ENTITIES Numeric and Special Graphic//EN//XML\" " >> $@
	@echo " \"http://www.oasis-open.org/docbook/xml/4.3/ent/iso-num.ent\">" >> $@
	@echo "<!ENTITY % ISOpub PUBLIC  " >> $@
	@echo " \"ISO 8879:1986//ENTITIES Publishing//EN//XML\" " >> $@
	@echo " \"http://www.oasis-open.org/docbook/xml/4.3/ent/iso-pub.ent\">" >> $@
	@echo "<!ENTITY % entities SYSTEM " >> $@
	@echo "             \"entity-decl.ent\"> "  >> $@
	@echo " %ISOlat1; %ISOlat2; %ISOnum; %ISOpub; %entities;]>" >> $@
	@echo "<docproperties xmlns=\"urn:x-suse:xmlns:docproperties\" version=\"1.0\">" >> $@
	@echo " <productspec>" >> $@
ifdef TITLE
	@echo "  <title>$(TITLE)</title>" >> $@
endif
	@echo "  <bookname>$(BOOK)</bookname>" >> $@
ifdef PRODUCTNAME
	@echo "  <productname>$(PRODUCTNAME)</productname>" >> $@
endif
ifdef PRODUCTNAMEREG
	@echo "  <productnamereg>$(PRODUCTNAMEREG)</productnamereg>" >> $@
endif
ifdef DISTVER
	@echo "  <productnumber>$(DISTVER)</productnumber>" >> $@
endif
ifdef HTMLROOT
	@echo "  <htmlroot>$(HTMLROOT)</htmlroot>" >> $@
endif
ifdef ROOTID
	@echo "  <rootid>$(ROOTID)</rootid>" >> $@
endif
ifdef MAIN
	@echo "  <main>$(MAIN)</main>" >> $@
endif
ifdef PROFOS
	@echo "  <profos>$(PROFOS)</profos>" >> $@
endif
ifdef PROFARCH
	@echo "  <profarch>$(PROFARCH)</profarch>" >> $@
endif
ifdef LAYOUT
	@echo "  <layout>$(LAYOUT)</layout>" >> $@
endif
ifdef PACKAGENAME
	@echo "  <packagename>$(PACKAGENAME)</packagename>" >> $@
endif
ifdef PDFNAME
	@echo "  <pdfname>$(PDFNAME)</pdfname>" >> $@
endif
ifdef REMARKS
	@echo "  <remark>$(REMARKS)</remark>" >> $@
endif
ifdef COMMENTS
	@echo "  <comments>$(COMMENTS)</comments>" >> $@
endif
	@echo " </productspec>" >> $@
	@echo "</docproperties>" >> $@


ifdef USESVN
# target to generate METAFILE for html stylesheets
.PHONY: meta profiled/$(PROFILEDIR)/METAFILE
meta: profiled/$(PROFILEDIR)/METAFILE
profiled/$(PROFILEDIR)/METAFILE: $(SRCFILES)
	echo "Generating $@..."
	@svn pl -v --xml $(SRCFILES) > tmp/.docprops.xml
	@xsltproc -o $@ $(METAXSLT) tmp/.docprops.xml

#profiled/$(PROFILEDIR)/%.xml.meta: xml/%.xml profiled/$(PROFILEDIR)
#	@echo "generating metafile for $<"
#	@echo "<filename " > $@
#	@svn pl -v $< |\
#	sed -n -e 's|doc:maintainer : \(.*\)|maintainer="\1"|p' \
#	       -e 's|doc:status : \(.*\)|status="\1"|p' \
#	       -e 's|doc:prelim : \(.*\)|prelim="\1"|p' \
#	       -e 's|doc:release : \(.*\)|release="\1"|p' >> $@
#	@echo ">$<</filename>" >> $@
endif

.PHONY: epub
epub: epub/$(TMP_BOOK).epub

epub/$(TMP_BOOK).epub: epub/$(BOOK).xml $(STYLEPUB) validate provide-epub-images
	$(DB2EPUB)\
		-s $(STYLEPUBXSLT)\
		--verbose --css $(STYLEPUBCSS)\
		-o $@ epub/$(BOOK).xml


epub/$(BOOK).xml: tmp/$(BOOK).xml
	xsltproc --output $@ $(ROOTSTRINGS) $(STYLEPUB) $<

.PHONY: wiki
wiki: wiki/$(BOOK)/$(ROOTID)

# Generate wiki from profiled xml
wiki/$(BOOK)/$(ROOTID): $(STYLEWIKI) $(PROFILES)
	mkdir -p wiki/$(BOOK)
	xsltproc --output $@.wiki $(ROOTSTRINGS) --xinclude $(STYLEWIKI) \
	         profiled/$(PROFILEDIR)/$(MAIN) 

# create text from bigfile html
txt/$(TMP_BOOK).txt: html/$(BOOK)/$(BOOK).html
	mkdir -p txt
	w3m -dump $< > $@

# helper targets for building html
html/$(BOOK):
	mkdir -p $@

html/$(BOOK)/$(notdir $(LSTYLECSS)): $(STYLECSS) html/$(BOOK) 
#	test -e html/$(BOOK)/$(notdir $(LSTYLECSS)) || ln -sf $(STYLECSS) html/$(BOOK)/
	ln -sf $(STYLECSS) html/$(BOOK)/

html/$(BOOK)/navig: $(DTDROOT)/images/navig html/$(BOOK) 
#	test -e html/$(BOOK)/navig || ln -sf $(DTDROOT)/images/navig html/$(BOOK)/
	ln -sf $(DTDROOT)/images/navig html/$(BOOK)/

html/$(BOOK)/admon: $(DTDROOT)/images/admon html/$(BOOK) 
#	test -e html/$(BOOK)/admon || ln -sf $(DTDROOT)/images/admon html/$(BOOK)/
	ln -sf $(DTDROOT)/images/admon html/$(BOOK)/

html/$(BOOK)/callouts: $(DTDROOT)/images/callouts/ html/$(BOOK) 
#	test -e html/$(BOOK)/callouts || ln -sf $(DTDROOT)/images/callouts/ html/$(BOOK)/
	ln -sf $(DTDROOT)/images/callouts/ html/$(BOOK)/

html/$(BOOK)/images: images/online/ html/$(BOOK) 
#	test -e html/$(BOOK)/images || ln -sf ../../images/online/ html/$(BOOK)/images
	ln -sf ../../images/online/ html/$(BOOK)/images


####
jsp/$(BOOK):
	mkdir -p $@

jsp/$(BOOK)/$(notdir $(LSTYLECSS)): $(STYLECSS) jsp/$(BOOK)
#       test -e jsp/$(BOOK)/$(notdir $(LSTYLECSS)) || ln -sf $(STYLECSS) jsp/$(BOOK)/
	ln -sf $(STYLECSS) jsp/$(BOOK)/

jsp/$(BOOK)/navig: $(DTDROOT)/images/navig jsp/$(BOOK)
#       test -e jsp/$(BOOK)/navig || ln -sf $(DTDROOT)/images/navig jsp/$(BOOK)/
	ln -sf $(DTDROOT)/images/navig jsp/$(BOOK)/

jsp/$(BOOK)/admon: $(DTDROOT)/images/admon jsp/$(BOOK)
#       test -e jsp/$(BOOK)/admon || ln -sf $(DTDROOT)/images/admon jsp/$(BOOK)/
	ln -sf $(DTDROOT)/images/admon jsp/$(BOOK)/

jsp/$(BOOK)/callouts: $(DTDROOT)/images/callouts/ jsp/$(BOOK)
#       test -e jsp/$(BOOK)/callouts || ln -sf $(DTDROOT)/images/callouts/ jsp/$(BOOK)/
	ln -sf $(DTDROOT)/images/callouts/ jsp/$(BOOK)/

jsp/$(BOOK)/images: images/online/ jsp/$(BOOK)
#       test -e jsp/$(BOOK)/images || ln -sf ../../images/online/ jsp/$(BOOK)/images
	ln -sf ../../images/online/ jsp/$(BOOK)/images


# Generate html from profiled xml
ifdef USESVN
html/$(BOOK)/index.html: meta html/$(BOOK)
endif
html/$(BOOK)/index.html: $(STYLEH) $(PROFILES) provide-color-images  warn-images $(HTMLGRAPHICS) html/$(BOOK)
	xsltproc $(HTMLSTRINGS) $(ROOTSTRING) $(METASTRING) $(MANIFEST) \
		 --stringparam projectfile PROJECTFILE.$(BOOK) \
	         --xinclude $(STYLEH) profiled/$(PROFILEDIR)/$(MAIN)
	if test "$(ROOTID)"; then \
		ln -sf $(ROOTID).html html/$(BOOK)/index.html;\
	fi

ifdef USESVN
html/$(BOOK)/$(BOOK).html: meta html/$(BOOK)
endif
html/$(BOOK)/$(BOOK).html: $(STYLEH) $(PROFILES) provide-color-images  warn-images $(HTMLGRAPHICS) html/$(BOOK)
	xsltproc $(HTMLSTRINGS) $(ROOTSTRING) $(METASTRING) $(MANIFEST) \
		 --stringparam projectfile PROJECTFILE.$(BOOK) \
		 --output html/$(BOOK)/$(BOOK).html \
	         --xinclude $(HTMLBIGFILE) profiled/$(PROFILEDIR)/$(MAIN) 

ifeq ("z$(INDEX)", "zYes")
profiled/$(PROFILEDIR)/$(TMP_BOOK).idx: $(PROFILES) profiled/$(PROFILEDIR)/.validate
	xsltproc $(ROOTSTRING) --xinclude --output $@ $(STYLEINDEX) \
	profiled/$(PROFILEDIR)/$(MAIN)

.idx.ind:
	$(DTDROOT)/bin/sortindexterms.py -l $(LL) $< --output $@
endif


# Generate JSP from profiled xml
ifdef USESVN
jsp/$(BOOK)/index.jsp: meta jsp/$(BOOK)
endif
jsp/$(BOOK)/index.jsp: $(STYLEJ) $(PROFILES) provide-color-images  warn-images $(HTMLGRAPHICS) jsp/$(BOOK)
	xsltproc $(JSPSTRINGS) $(ROOTSTRING) $(METASTRING) $(XHTMLSTRING) $(MANIFEST) \
                 --stringparam projectfile PROJECTFILE.$(BOOK) \
                 --xinclude $(STYLEJ) profiled/$(PROFILEDIR)/$(MAIN)
	if test "$(ROOTID)"; then \
                ln -sf $(ROOTID).jsp jsp/$(BOOK)/index.jsp;\
        fi



# Generate fo from xml
ifeq ("z$(INDEX)", "zYes")
tmp/$(TMP_BOOK)-$(FOPTYPE).fo: profiled/$(PROFILEDIR)/$(TMP_BOOK).ind
endif
tmp/$(TMP_BOOK)-$(FOPTYPE).fo: $(PROFILES) $(STYLEFO) profiled/$(PROFILEDIR)/.validate
	xsltproc --xinclude $(FOSTRINGS) $(ROOTSTRING) $(INDEXSTRING) \
		--stringparam projectfile PROJECTFILE.$(BOOK) \
		-o $@ $(STYLEFO) \
	profiled/$(PROFILEDIR)/$(MAIN)
	@echo -e "\033[32m***********Created fo                 ....\033[0m\017"

ifeq ("z$(INDEX)", "zYes")
tmp/$(TMP_BOOK)-$(FOPTYPE).fo: profiled/$(PROFILEDIR)/$(TMP_BOOK).ind
endif
tmp/$(TMP_BOOK)-$(FOPTYPE)-online.fo: $(PROFILES) $(STYLEFO) provide-color-images profiled/$(PROFILEDIR)/.validate
	xsltproc --xinclude $(FOCOLSTRINGS) $(ROOTSTRING) $(INDEXSTRING) \
		--stringparam projectfile PROJECTFILE.$(BOOK) \
		-o $@ $(STYLEFO) \
	profiled/$(PROFILEDIR)/$(MAIN)

# Create pdf from fo
ifeq ($(FOPTYPE), fop)
%-online.pdf: tmp/%-online.fo provide-color-images warn-images $(FOP_CONFIG_FILE)
	FOP_CONFIG_FILE=$(FOP_CONFIG_FILE) $(FOP) $(FOPOPTIONS) $< $@
else
%-online.pdf: tmp/%-online.fo provide-color-images warn-images $(XEP_CONFIG_FILE)
	XEP_CONFIG_FILE=$(XEP_CONFIG_FILE) $(FOP) $(FOPOPTIONS) $< $@
endif
	@if test "$(MISSING)"; then \
	    echo "Possibly missing graphics files: $(MISSING)"; \
	fi
	@echo -e "\033[32mBook $@ built with COMMENTS=$(COMMENTS) and REMARKS=$(REMARKS)\033[m\017"
	@pdffonts $@ | grep -v -e "^name" -e "^---" | cut -c 51-71 | \
		grep -v -e "yes yes yes" >& /dev/null && \
		(echo -en "\033[31m"; echo Warning: not all fonts are embedded; echo -en "\033[0m\017";) || :

ifeq ($(FOPTYPE), fop)
%.pdf: tmp/%.fo provide-images warn-images $(FOP_CONFIG_FILE)
	FOP_CONFIG_FILE=$(FOP_CONFIG_FILE) $(FOP) $(FOPOPTIONS) $< $@
else
%.pdf: tmp/%.fo provide-images warn-images $(XEP_CONFIG_FILE)
	XEP_CONFIG_FILE=$(XEP_CONFIG_FILE) $(FOP) $(FOPOPTIONS) $< $@
endif
	@if test "$(MISSING)"; then \
	    echo "Possibly missing graphics files: $(MISSING)"; \
	fi
	@echo -e "\033[32mBook $@ built with COMMENTS=$(COMMENTS) and REMARKS=$(REMARKS)\033[m\017"
	@pdffonts $@ | grep -v -e "^name" -e "^---" | cut -c 51-71 | \
		grep -v -e "yes yes yes" >& /dev/null && \
		(echo -en "\033[31m"; echo Warning: not all fonts are embedded; echo -en "\033[0m\017";) || :

# Create ps from fo (might not work if fonts are not setup correctly
# for the fop processor)
%.ps: %.pdf
	pdftops $<

$(PROFILES): profiled/$(PROFILEDIR)/PROJECTFILE.$(BOOK)
$(TMPDIST): tmp/dist/PROJECTFILE.$(BOOK)
force_target: ;
