# help targets for the make environment
.PHONY: help
help:
	@echo "Syntax:"
	@echo "make [ROOTID=<id>] [Target] [ENV-Variables]*"
	@echo ""
	@echo "This process is used to transform the XML sources of a book project"
	@echo "into PDF or HTML. The default target is pdf."
	@echo ""
	@echo "Targets for building books:"
	@echo "---------------------------"
	@echo ""
	@echo "html        make html book in subdirectory html/\$$(BOOK). When using the "
	@echo "            ROOTID feature, the resulting chapter is found at "
	@echo "            html/\$$(BOOK)/<id>.html"
	@echo "html-single make a single html book in subdirectory html/\$$(BOOK)/"
	@echo "            as filename\$$(BOOK).html."
	@echo "jsp         make html book in subdirectory jsp/\$$(BOOK) as JSP format"
	@echo "            can be combined with USEXHTML to create XHTML pages only"
	@echo "txt         create a single text file of the complete document"
	@echo "wiki        prepare the document for mediawiki"
	@echo "pdf         make book for printing with cropmarks and gray"
	@echo "force       like pdf, but force the profiling step to be redone"
	@echo "color-pdf   create online book without cropmarks and in color. Resulting "
	@echo "            name is \$$(BOOK)-online.pdf"
	@echo "desktop-files"
	@echo "            build the .desktop files for the Help Center (KDE) and Yelp (GNOME)"
	@echo ""
	@echo ""
	@echo "Targets for exporting the docs:"
	@echo "-------------------------------"
	@echo ""
	@echo "dist-xml    create zip archives of the xml files needed for the current"
	@echo "            book. Two archives are created, one with all profiled xml"
	@echo "            files, and a second one -- filename extended with src --"
	@echo "            with the unprofiled sources. The whole set is packaged"
	@echo "            without looking at the \$$(ROOTID):"
	@echo ""
	@echo "dist-book   similar to dist-xml, but creates a tar.bz2 archive with"
	@echo "            profiled sources and all xml files below a subdirectory xml/."
	@echo "            This also includes Makefile and the environmentfile, if "
	@echo "            its name is ENV-\$$(BOOK). This target uses only files "
	@echo "            that are included after \$$(ROOTID)."
	@echo ""
	@echo "dist-graphics create an archive of all images used in the current book."
	@echo "            Only source images are packed, the automatically generated"
	@echo "            images are ignored."
	@echo ""
	@echo "dist-html   make a html book, and provide it in an tar.bz2 archive."
	@echo ""
	@echo "locdrop     create two .tar.bz2 archives that contains all needed files "
	@echo "            to create a book. One of them contains the files to be"
	@echo "            translated, the other one contains all the remaining files."
	@echo ""
	@echo "package     create a set of files needed to submit the book to autobuild"
	@echo ""
	@echo "online-docs create a set of xml source files and pictures used for our"
	@echo "            web presence"
	@echo ""
	@echo ""
	@echo "Other Targets:"
	@echo "--------------"
	@echo ""
	@echo "validate    do profiling and then validate the selected book."
	@echo "chklink     create a list of all links in the project, and check if "
	@echo "            they are available right now."
	@echo ""
	@echo "update      update the stylesheets, DTD and make mechanics"
	@echo "configure   configure system and install suse adjustments for xep"
	@echo "directories create all the directories for a new project. At least, "
	@echo "            the ENV- file and Makefile must be there and point to the "
	@echo "            DTDROOT. See also the documentation for this build process"
	@echo "check       print several internally used variables"
	@echo "help        this help"
	@echo "help-variables list all environment variables that have an effect on building"

.PHONY: help-variables
help-variables:
	@echo "The following variables may be defined and exported from the shell."
	@echo "Commonly, these are unset in \$$(DTDROOT), to avoid unexpected effects"
	@echo "when sourcing a new environment file. If you want to use a personal"
	@echo "setting, you must change or set the variable after sourceing the selected"
	@echo "project file."
	@echo ""
	@echo "DTDROOT       The main directory, where all stylesheets and makefiles reside"
	@echo "              If you want to change this, you also have to edit your "
	@echo "              ENV- file and the Makefile in your project directory."
	@echo "CHECKBOT      Used for the target chklink and points to an executable"
	@echo "CB_OPTIONS    Sets the options for \$$(CHECKBOT)"
	@echo "TESTPAGE      Name for the checkbot testpage"
	@echo "CONVERT_OPTS  Options for ImageMagick to convert color to gray"
	@echo "INK_OPTIONS   Options for Inkscape to convert SVG to PNG"
	@echo "FOPTIONS      Options for the FOP processor"
	@echo "REMARKS       Switch remarks on or off when profiling (1=on, 0=off (default))"
	@echo "COMMENTS      Switch XML comments on or off when profiling (1=on, 0=off (default))"
	@echo "STYLEFO       Select stylesheet for fo generation"
	@echo "ROOTID        Select the toplevel id for the document to build"
	@echo "DRAFT         Switch on the draft mode for PDF generation (yes, no (default))"
	@echo "LL            Language identifier that is also used in filenames"
	@echo "FOP           Manually select, which pdf generator to use"
	@echo "STYLENOV      Profiling stylsheet for novdoc"
	@echo "PDFNAME       Name of the resulting PDF (use with care)"
	@echo "USEMETA       use meta information files when generating html to document"
	@echo "              status of the xml documentation (from svn)"
	@echo "USEXHTML      turns off JSP page transformations and outputs just XHTML"
	@echo ""
	@echo ""
	@echo ""
	@echo "Profiling attributes:"
	@echo "PROFARCH      Profiling for different architectures. This has an influence on"
	@echo "              so called architecture brackets in the resulting document"
	@echo "PROFOS        Used to include specific sections only in the relevant book"
	@echo "PROFCONDITION Made to be able to generate internal and external versions of a"
	@echo "              Document"
