.PHONY: unpacked-document-files-html
unpacked-document-files-html: $(PROFILES)
# if $ROOTSTRINGS is empty, it is a set and writes contents to files
ifeq ($(ROOTSTRINGS),)
	xsltproc $(DESKSTRINGS) $(ROOTSTRINGS) --nonet \
		--stringparam projectfile PROJECTFILE.$(BOOK) \
		--stringparam outformat html \
		--stringparam docid com.novell.$(BOOK)$(subst _,,$(LL)) \
	        --xinclude $(STYLE_DOCUMENT) \
		profiled/$(PROFILEDIR)/$(MAIN)
else
	mkdir -p yelp-html/yelp
	xsltproc $(DESKSTRINGS) $(ROOTSTRINGS) --nonet \
		--stringparam projectfile PROJECTFILE.$(BOOK) \
		--stringparam outformat html \
		--stringparam docid com.novell.$(BOOK)$(subst _,,$(LL)) \
	        --xinclude $(STYLE_DOCUMENT) \
		profiled/$(PROFILEDIR)/$(MAIN) \
		>yelp-html/yelp/$(BOOK)_$(LL).document
endif

.PHONY: document-files-html
document-files-html: unpacked-document-files-html
	test -d yelp-html/yelp \
	  && BZIP2=--best tar cjf $(TMP_BOOK)_$(LL)-yelp.tar.bz2 \
		-C yelp-html yelp \
	  || echo "No document files available"
	rm -rf yelp-html

.PHONY: unpacked-document-files-pdf
unpacked-document-files-pdf: $(PROFILES)
	mkdir -p yelp-pdf/yelp
	xsltproc $(DESKSTRINGS) $(ROOTSTRINGS) --nonet \
		--stringparam projectfile PROJECTFILE.$(BOOK) \
		--stringparam outformat pdf \
		--stringparam docid com.novell.$(BOOK)$(subst _,,$(LL))pdf \
	        --xinclude $(STYLE_DOCUMENT) \
		profiled/$(PROFILEDIR)/$(MAIN) \
		>yelp-pdf/yelp/$(BOOK)_$(LL)-pdf.document

.PHONY: document-files-pdf
document-files-pdf: unpacked-document-files-pdf
	test -d yelp-pdf/yelp \
	  && BZIP2=--best tar cjf $(TMP_BOOK)_$(LL)-pdf-yelp.tar.bz2 \
		-C yelp-pdf yelp \
	  || echo "No document files available"
	rm -rf yelp-pdf

.PHONY: unpacked-desktop-files
unpacked-desktop-files: $(PROFILES)
	xsltproc $(DESKSTRINGS) $(ROOTSTRINGS) --nonet \
		--stringparam projectfile PROJECTFILE.$(BOOK) \
	         --xinclude $(STYLEDESK) profiled/$(PROFILEDIR)/$(MAIN)

.PHONY: desktop-files
desktop-files: unpacked-desktop-files
	test -d desktop && BZIP2=--best tar cjf $(TMP_BOOK)_$(LL)-desktop.tar.bz2 desktop || echo "No desktop files available"
	rm -rf desktop

.PHONY: package
package: INCLUDED=$(shell xsltproc --nonet --xinclude $(ROOTSTRINGS) $(STYLESEARCH) \
	                   profiled/dist/$(MAIN)) $(MAIN)
package: dist-html color-pdf dist-graphics dist-book document-files-pdf
	mkdir -p package-${BOOK}
ifneq ("z$(USED_SVG)$(USED_PNG)", "z")
	mv $(TMP_BOOK)_$(LL)-graphics.tar.bz2 package-$(BOOK)/$(BOOK)_$(LL)-graphics.tar.bz2
endif
	mv $(TMP_BOOK)_$(LL)-html.tar.bz2 package-$(BOOK)/$(BOOK)_$(LL)-html.tar.bz2
	test -f $(TMP_BOOK)_$(LL)-desktop.tar.bz2 && \
	mv $(TMP_BOOK)_$(LL)-desktop.tar.bz2 package-$(BOOK)/$(BOOK)_$(LL)-desktop.tar.bz2 || \
	echo "No desktop files available"
	test -f $(TMP_BOOK)_$(LL)-yelp.tar.bz2 && \
	mv $(TMP_BOOK)_$(LL)-yelp.tar.bz2 package-$(BOOK)/$(BOOK)_$(LL)-yelp.tar.bz2 || \
	echo "No document files available"
	mv $(TMP_BOOK)-$(FOPTYPE)-online.pdf package-$(BOOK)/$(BOOK)_$(LL).pdf
	test -f $(TMP_BOOK)_$(LL)-pdf-yelp.tar.bz2 && \
	mv $(TMP_BOOK)_$(LL)-pdf-yelp.tar.bz2 package-$(BOOK)/$(BOOK)_$(LL)-pdf-yelp.tar.bz2 || \
	echo "No PDF document files available"
	mv $(BOOK)_$(LL).tar.bz2 package-$(BOOK)/$(BOOK)_$(LL).tar.bz2
	@echo "checking for unexpected characters:"
	egrep -n "[^[:print:]]" $(addprefix xml/,$(INCLUDED)) && echo "FAILED" || echo "OK"

# contains everything needed for html -- html, graphics, desktop files, dist-book
.PHONY: package-html
package-html: INCLUDED=$(shell xsltproc --nonet  --xinclude $(ROOTSTRINGS) $(STYLESEARCH) \
	                   profiled/dist/$(MAIN)) $(MAIN)
package-html: dist-html dist-graphics dist-book
	mkdir -p package-html-${BOOK}
ifneq ("z$(USED_SVG)$(USED_PNG)", "z")
	mv $(TMP_BOOK)_$(LL)-graphics.tar.bz2 package-html-$(BOOK)/$(BOOK)_$(LL)-graphics.tar.bz2
endif
	mv $(TMP_BOOK)_$(LL)-html.tar.bz2 package-html-$(BOOK)/$(BOOK)_$(LL)-html.tar.bz2
	test -f $(TMP_BOOK)_$(LL)-desktop.tar.bz2 && \
	mv $(TMP_BOOK)_$(LL)-desktop.tar.bz2 package-html-$(BOOK)/$(BOOK)_$(LL)-desktop.tar.bz2 || \
	echo "No desktop files available"
	test -f $(TMP_BOOK)_$(LL)-yelp.tar.bz2 && \
	mv $(TMP_BOOK)_$(LL)-yelp.tar.bz2 package-html-$(BOOK)/$(BOOK)_$(LL)-yelp.tar.bz2 || \
	echo "No document files available"
	mv $(BOOK)_$(LL).tar.bz2 package-html-$(BOOK)/$(BOOK)_$(LL).tar.bz2
	@echo "checking for unexpected characters:"
	egrep -n "[^[:print:]]" $(addprefix xml/,$(INCLUDED)) && echo "FAILED" || echo "OK"

.PHONY: package-jsp
package-jsp: INCLUDED=$(shell xsltproc --nonet  --xinclude $(ROOTSTRINGS) $(STYLESEARCH) \
	                   profiled/dist/$(MAIN)) $(MAIN)
package-jsp: dist-jsp dist-graphics dist-book
	mkdir -p package-jsp-${BOOK}
ifneq ("z$(USED_SVG)$(USED_PNG)", "z")
	mv $(TMP_BOOK)_$(LL)-graphics.tar.bz2 package-jsp-$(BOOK)/$(BOOK)_$(LL)-graphics.tar.bz2
endif
	mv $(TMP_BOOK)_$(LL)-jsp.tar.bz2 package-jsp-$(BOOK)/$(BOOK)_$(LL)-jsp.tar.bz2
	mv $(BOOK)_$(LL).tar.bz2 package-jsp-$(BOOK)/$(BOOK)_$(LL).tar.bz2
	@echo "checking for unexpected characters:"
	egrep -n "[^[:print:]]" $(addprefix xml/,$(INCLUDED)) && echo "FAILED" || echo "OK"

# contains color-pdf dist-book
.PHONY: package-pdf
package-pdf: INCLUDED=$(shell xsltproc --nonet  --xinclude $(ROOTSTRINGS) $(STYLESEARCH) \
	                   profiled/dist/$(MAIN)) $(MAIN)
package-pdf: color-pdf dist-book document-files-pdf
	mkdir -p package-pdf-${BOOK}
	mv $(TMP_BOOK)-$(FOPTYPE)-online.pdf package-pdf-$(BOOK)/$(BOOK)_$(LL).pdf
	test -f $(TMP_BOOK)_$(LL)-pdf-yelp.tar.bz2 && \
	mv $(TMP_BOOK)_$(LL)-pdf-yelp.tar.bz2 package-pdf-$(BOOK)/$(BOOK)_$(LL)-pdf-yelp.tar.bz2 || \
	echo "No PDF document files available"
	mv $(BOOK)_$(LL).tar.bz2 package-pdf-$(BOOK)/$(BOOK)_$(LL).tar.bz2
	@echo "checking for unexpected characters:"
	egrep -n "[^[:print:]]" $(addprefix xml/,$(INCLUDED)) && echo "FAILED" || echo "OK"

.PHONY: locdrop
locdrop: validate
locdrop: TOTRANSFILES=$(shell dm.py dg -P --include="doc:trans=yes" -H -A -q "%{name} ")
locdrop: QUIET=@
locdrop: INCLUDED=$(shell xsltproc --nonet $(ROOTSTRINGS) --xinclude $(STYLESEARCH) \
	                   profiled/dist/$(MAIN)) $(MAIN) 
locdrop: dist-xml dist-graphics color-pdf
	rm -rf locdrop-$(BOOK)
	mkdir -p locdrop-$(BOOK)/xml
	mv $(shell make color-pdf-name) locdrop-$(BOOK)
	cd locdrop-$(BOOK) && tar xjf ../$(BOOK)_$(LL).tar.bz2
	cd locdrop-$(BOOK) && BZIP2=--best tar cjf ../locdrop-totrans-$(BOOK).tar.bz2 $(TOTRANSFILES)
	cd locdrop-$(BOOK) && rm $(TOTRANSFILES)
	cd locdrop-$(BOOK) && BZIP2=--best tar cjf ../locdrop-$(BOOK).tar.bz2 .
	cd locdrop-$(BOOK) && rm -rf *
	mv locdrop-$(BOOK).tar.bz2 locdrop-$(BOOK)
	mv locdrop-totrans-$(BOOK).tar.bz2 locdrop-$(BOOK)
ifneq ("z$(USED_SVG)$(USED_PNG)", "z")
	mv $(TMP_BOOK)_$(LL)-graphics.tar.bz2 locdrop-$(BOOK)
	@echo "created locdrop-$(BOOK)/$(TMP_BOOK)_$(LL)-graphics.tar.bz2, "
endif
	@echo "checking for unexpected characters:"
	egrep -n "[^[:print:]]" $(addprefix xml/,$(INCLUDED)) && echo "FAILED" || echo "OK"
	@echo "created locdrop-$(BOOK)/locdrop-$(BOOK).tar.bz2 and "
	@echo "locdrop-$(BOOK)/locdrop-totrans-$(BOOK).tar.bz2. You still should unpack"
	@echo "these archives and at least run "
	@echo "make validate html color-pdf"

.PHONY: online-docs
online-docs: dist-graphics-png online-docs-$(BOOK)/$(MAIN)
ifneq ("z$(USED)", "z")
	mv $(TMP_BOOK)_$(LL)-png-graphics.tar.bz2 online-docs-$(BOOK)/
endif
	# mv $(TMP_BOOK)-$(FOPTYPE)-online.pdf online-docs-$(BOOK)/
	@echo -en "\033[32m"
	@echo "Sources for online documentation copied to online-docs-$(BOOK)/"
	@echo -en "\033[m\017"

.PHONY: online-localized
online-localized: dist-graphics-png online-localized-$(BOOK)/$(MAIN)
ifneq ("z$(USED)", "z")
	mv $(TMP_BOOK)_$(LL)-png-graphics.tar.bz2 online-localized-$(BOOK)/
endif
	# mv $(TMP_BOOK)-$(FOPTYPE)-online.pdf online-localized-$(BOOK)/
	@echo -en "\033[32m"
	@echo "Sources for online documentation copied to online-localized-$(BOOK)/"
	@echo -en "\033[m\017"

