<?xml version="1.0" encoding="UTF-8"?>
<!-- $Id: $ -->
<!DOCTYPE xsl:stylesheet>
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:fo="http://www.w3.org/1999/XSL/Format">




<!-- ==================================================================== -->
<!-- Suppress titles -->
<xsl:template match="procedure">
  <xsl:variable name="id">
    <xsl:call-template name="object.id"/>
  </xsl:variable>

  <xsl:variable name="param.placement"
                select="substring-after(normalize-space($formal.title.placement),
                                        concat(local-name(.), ' '))"/>
  <xsl:variable name="count.steps"
                select="count(step)"/>

  <xsl:variable name="placement">
    <xsl:choose>
      <xsl:when test="contains($param.placement, ' ')">
        <xsl:value-of select="substring-before($param.placement, ' ')"/>
      </xsl:when>
      <xsl:when test="$param.placement = ''">before</xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$param.placement"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <!-- Preserve order of PIs and comments -->
  <xsl:variable name="preamble"
        select="*[not(self::step
                  or self::title
                  or self::titleabbrev)]
                |comment()[not(preceding-sibling::step)]
                |processing-instruction()[not(preceding-sibling::step)]"/>

  <xsl:variable name="steps"
                select="step
                        |comment()[preceding-sibling::step]
                        |processing-instruction()[preceding-sibling::step]"/>


  <fo:block id="{$id}" xsl:use-attribute-sets="list.block.spacing">
    <xsl:if test="./title and $placement = 'before'">
      <!-- n.b. gentext code tests for $formal.procedures and may make an "informal" -->
      <!-- heading even though we called formal.object.heading. odd but true. -->
<!--       <xsl:call-template name="formal.object.heading"/> -->
          <xsl:apply-templates select="title" mode="object.title.markup"/>
    </xsl:if>

    <xsl:apply-templates select="$preamble"/>

    <fo:list-block xsl:use-attribute-sets="list.block.spacing">
       <xsl:choose>
          <xsl:when test="$count.steps &lt; 10">
            <xsl:attribute name="provisional-distance-between-starts">18pt</xsl:attribute>
            <xsl:attribute name="provisional-label-separation">6pt</xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:attribute name="provisional-distance-between-starts">20pt</xsl:attribute>
            <xsl:attribute name="provisional-label-separation">6pt</xsl:attribute>
<!--             <xsl:attribute name="text-align">right</xsl:attribute> -->
          </xsl:otherwise>
       </xsl:choose>
        <xsl:apply-templates select="$steps"/>
    </fo:list-block>

    <xsl:if test="./title and $placement != 'before'">
      <!-- n.b. gentext code tests for $formal.procedures and may make an "informal" -->
      <!-- heading even though we called formal.object.heading. odd but true. -->
<!--       <xsl:call-template name="formal.object.heading"/> -->
      <xsl:apply-templates select="title" mode="object.title.markup"/>
    </xsl:if>

  </fo:block>
</xsl:template>

<xsl:template match="procedure/title" mode="object.title.markup">
   <xsl:param name="allow-anchors"/>

   <fo:block xsl:use-attribute-sets="procedure.title.properties">
     <xsl:apply-templates/>
   </fo:block>
</xsl:template>

<!-- ******************************************************************* -->

<xsl:template match="varlistentry" mode="vl.as.blocks">
  <xsl:variable name="id"><xsl:call-template name="object.id"/></xsl:variable>

  <fo:block id="{$id}" xsl:use-attribute-sets="list.item.spacing"
      keep-together.within-column="always"
      keep-with-next.within-column="always">
    <xsl:apply-templates select="term"/>
  </fo:block>

  <fo:block margin-left="1.25em">
    <xsl:apply-templates select="listitem"/>
  </fo:block>
</xsl:template>



</xsl:stylesheet>
